# MCMAlgorithms
This package includes some commonly use algorithms in mathematical modeling. 
## Dependent Package
* numpy >= 1.18.1
* pandas >= 1.0.3
* scipy >= 1.4.1
## Algorithms
### Classification
Waiting for complement.
### Evaluation
Relationship Comparison: Grey Relationshgip Analysis, Data Envelope Analysis, TOPSIS, RSR.

Weight Calculation: AHP, Entropy weighting.
### Optimization
Animals: Particle Swarm Optimization (PSO).

Evolution: Genetic Algorithm (GA).

Single: Simulated Annealing, Tabu search.
### Regression
Simple: Linear Regression.

TimeSeries: GM(1,1) prediction (grey prediction).
### Mining
BasicAssociationRule: Apriori, FP-Growth, Eclat and association rule generation.